@@ -1,3 +1,4 @@
+from capris.core import run_command
 from capris.runnable import Runnable
 
 class Pipe(Runnable):
@@ -10,6 +11,10 @@ class Pipe(Runnable):
             stack.append(str(item))
         return ' | '.join(stack)
 
+    def __iter__(self):
+        for item in self.commands:
+            yield list(item)
+
     def append(self, command):
         self.commands.append(command)
         return self
